@@ -23,7 +23,7 @@ RULE_VARIABLES = "variables"
 ENCODINGS = "encodings"
 RESULT = "result"
 INDICES = "indices"
-LOGGING = "logging"
+LOG = "log"
 RESULT_EXPRESSION = "result_expression"
 
 DUNDER_DF = "_df"
@@ -36,3 +36,6 @@ VAR_NOT_X = "~X"
 VAR_Y = "Y"
 VAR_NOT_Y = "~Y"
 VAR_N = "N"
+
+COMPARISONS = "comparisons"
+STATISTICS = "statistics"
