@@ -6,99 +6,8 @@ from typing import Dict
 
 from .const import DUNDER_DF
 from .const import VAR_X
-from .const import VAR_NOT_X
 from .const import VAR_Y
-from .const import VAR_NOT_Y
 from .const import VAR_N
-from .const import VAR_X_AND_Y
-from .const import VAR_X_AND_NOT_Y
-from .const import VAR_NOT_X_AND_NOT_Y
-
-
-def dataframe_lengths(
-    expression: str,
-    required: list,
-    data: pd.DataFrame,
-) -> Dict[str, str]:
-    """
-    Calculate lengths based on an rule expression and generate corresponding values.
-
-    This function takes a rule expression, such as 'if A then B', and a list
-    of required variables ('N', 'X', 'Y', '~X', '~Y', 'X and Y', 'X and ~Y',
-    '~X and ~Y'). It calculates lengths or sums of data based on the given
-    conditional expression for each required variable.
-
-    Args:
-        expression (str): A conditional expression in the format 'if A then B'.
-        required (List[str]): A list of required variables for which to calculate
-        lengths or sums.
-
-    Returns:
-        Dict[str, str]: A dictionary where keys are required variable names, and
-        values are corresponding length or sum calculations.
-
-    Example:
-        >>> expression = "if ({"A"} > 0) then ({"B"} < 10)"
-        >>> required = ['X', 'Y', 'X and Y']
-        >>> result = ruleminer.dataframe_lengths(expression, required)
-        >>> print(result)
-        {'X': '((_df["A"] > 0)).sum()', 'Y': '((_df["B"] < 10)).sum()',
-        'X and Y': '(((_df["A"] > 0)) & ((_df["B"] < 10))).sum()'}
-    """
-    regex_condition = re.compile(r"if(.*)then(.*)", re.IGNORECASE)
-    rule = regex_condition.search(expression)
-
-    if_part = rule.group(1).strip()
-    then_part = rule.group(2).strip()
-
-    expressions = {}
-    for variable in required:
-        if variable == VAR_N:
-            expressions[variable] = "len(" + DUNDER_DF + ".values)"
-        if variable == VAR_X:
-            if if_part == "()":
-                expressions[variable] = "len(" + DUNDER_DF + ".index)"
-            else:
-                expressions[variable] = "(" + pandas_column(if_part, data) + ").sum()"
-        elif variable == VAR_NOT_X:
-            if if_part == "()":
-                expressions[variable] = "0"
-            else:
-                expressions[variable] = "(~(" + pandas_column(if_part, data) + ")).sum()"
-        elif variable == VAR_Y:
-            expressions[variable] = "(" + pandas_column(then_part, data) + ").sum()"
-        elif variable == VAR_NOT_Y:
-            expressions[variable] = "(~(" + pandas_column(then_part, data) + ")).sum()"
-        elif variable == VAR_X_AND_Y:
-            expressions[variable] = (
-                "(("
-                + pandas_column(if_part, data)
-                + ") & ("
-                + pandas_column(then_part, data)
-                + ")).sum()"
-            )
-        elif variable == VAR_X_AND_NOT_Y:
-            expressions[variable] = (
-                "(("
-                + pandas_column(if_part, data)
-                + ") & ~("
-                + pandas_column(then_part, data)
-                + ")).sum()"
-            )
-        elif variable == VAR_NOT_X_AND_NOT_Y:
-            expressions[variable] = (
-                "(~("
-                + pandas_column(if_part, data)
-                + ") & ~("
-                + pandas_column(then_part, data)
-                + ")).sum()"
-            )
-
-    for e in expressions.keys():
-        expressions[e] = expressions[e].replace("[(())]", "")
-        expressions[e] = expressions[e].replace("(()) & ", "")
-        expressions[e] = expressions[e].replace("[~(())]", "[False]")
-    return expressions
 
 
 def dataframe_index(
