@@ -43,9 +43,11 @@ class RuleParser:
             (set(["sumif"]), self.parse_sumif),
             (set(["countif"]), self.parse_countif),
             (set(["match"]), self.parse_match),
+            (set(["contains", "not contains"]), self.parse_contains),
             (set(["exact"]), self.parse_exact),
             (set(["corr"]), self.parse_corr),
             (set(["max", "min", "abs"]), self.parse_maxminabs),
+            (set(["round", "floor", "ceil"]), self.parse_round),
             (
                 set(
                     [
@@ -281,6 +283,49 @@ class RuleParser:
         )
         return res
 
+    def parse_round(
+        self,
+        idx: int,
+        item: str,
+        expression: Union[str, list],
+        apply_tolerance: bool = False,
+        positive_tolerance: bool = True,
+    ) -> str:
+        """
+        Process round function
+
+        Example:
+            expression = ['CEIL', ['(', '{"d"}', ',', '2', ')']]
+            idx = 0
+
+            result = ruleminer.RuleParser().parse_round(
+                idx=idx,
+                expression=expression,
+                apply_tolerance=False
+            )
+            print(result)
+                '_round({"d"}, 2, "ceil")'
+        """
+        _, data_series, _, rounding_param, _ = expression[idx + 1]
+        res = (
+            "_round("
+            + self.parse(
+                data_series,
+                apply_tolerance=apply_tolerance,
+                positive_tolerance=positive_tolerance,
+            )
+            + ", "
+            + self.parse(
+                rounding_param,
+                apply_tolerance=apply_tolerance,
+                positive_tolerance=positive_tolerance,
+            )
+            + ', "'
+            + item.lower()
+            + '")'
+        )
+        return res
+
     def parse_timedate_function(
         self,
         idx: int,
@@ -744,10 +789,12 @@ class RuleParser:
                 expression=flatten(expression[idx : idx + 2]),
                 data=self.data,
             )
-            evaluator = CodeEvaluator()
+            evaluator = CodeEvaluator(self.params)
             evaluator.set_params(self.params)
             evaluator.set_data(self.data)
-            quantile_result, _ = evaluator.evaluate_str(expression=quantile_code, encodings={})
+            quantile_result, _ = evaluator.evaluate_str(
+                expression=quantile_code, encodings={}
+            )
             res += str(np.round(quantile_result, 8))
             return res
         else:
@@ -897,7 +944,7 @@ class RuleParser:
             )
             if item in ["=="]:
                 res = (
-                    "_equal("
+                    "_eq("
                     + left_side
                     + ", "
                     + right_side
@@ -913,7 +960,7 @@ class RuleParser:
                 )
             if item in ["!="]:
                 res = (
-                    "_unequal("
+                    "_ne("
                     + left_side
                     + ", "
                     + right_side
@@ -927,9 +974,41 @@ class RuleParser:
                     + right_side_neg
                     + ")"
                 )
-            elif item in [">", ">="]:
+            if item in [">="]:
+                res = (
+                    "_ge("
+                    + left_side
+                    + ", "
+                    + right_side
+                    + ", "
+                    + left_side_pos
+                    + ", "
+                    + left_side_neg
+                    + ", "
+                    + right_side_pos
+                    + ", "
+                    + right_side_neg
+                    + ")"
+                )
+            if item in ["<="]:
+                res = (
+                    "_le("
+                    + left_side
+                    + ", "
+                    + right_side
+                    + ", "
+                    + left_side_pos
+                    + ", "
+                    + left_side_neg
+                    + ", "
+                    + right_side_pos
+                    + ", "
+                    + right_side_neg
+                    + ")"
+                )
+            elif item in [">"]:
                 res = left_side_pos + item + right_side_neg
-            elif item in ["<", "<="]:
+            elif item in ["<"]:
                 res = left_side_neg + item + right_side_pos
         else:
             left_side = expression[:idx]
@@ -1213,6 +1292,52 @@ class RuleParser:
             )
         return res + ", na=False)"
 
+    def parse_contains(
+        self,
+        idx: int,
+        item: str,
+        expression: Union[str, list],
+        apply_tolerance: bool = False,
+        positive_tolerance: bool = True,
+    ) -> str:
+        """
+        Process match operator
+
+        Example:
+            expression = ['{"A"}', 'contains', '"A"']
+
+            result = ruleminer.RuleParser().parse_match(
+                idx=1,
+                expression=expression,
+                apply_tolerance=False
+            )
+            print(result)
+                '
+                ({"A"}.str.contains("A"))
+                '
+        """
+        left_side = expression[:idx]
+        right_side = expression[idx + 1 :]
+        # process in operator
+        if item.lower() == "not contains":
+            res = "~"
+        else:
+            res = ""
+        for i in left_side:
+            res += self.parse(
+                i,
+                apply_tolerance=apply_tolerance,
+                positive_tolerance=positive_tolerance,
+            )
+        res += ".str.contains("
+        for i in right_side:
+            res += self.parse(
+                i,
+                apply_tolerance=apply_tolerance,
+                positive_tolerance=positive_tolerance,
+            )
+        return res + ", na=False)"
+
     def parse_exact(
         self,
         idx: int,
