@@ -28,7 +28,6 @@ from .evaluator import CodeEvaluator
 from .pandas_parser import (
     dataframe_index,
     dataframe_values,
-    dataframe_lengths,
 )
 from .utils import (
     flatten,
@@ -40,7 +39,7 @@ from .metrics import (
     metrics,
     required_variables,
     calculate_metrics,
-    calculate_required_variables,
+    add_required_variables,
 )
 from .const import (
     CONFIDENCE,
@@ -55,9 +54,9 @@ from .const import (
     INDICES,
     ENCODINGS,
     VAR_X_AND_Y,
-    VAR_NOT_X, 
+    VAR_NOT_X,
     VAR_X_AND_NOT_Y,
-    # LOGGING,
+    LOG,
 )
 
 
@@ -85,7 +84,7 @@ class RuleMiner:
         """ """
         self.params = dict()
         self.parser = RuleParser()
-        self.evaluator = CodeEvaluator()
+        self.evaluator = CodeEvaluator(params)
         self.update(templates=templates, rules=rules, data=data, params=params)
 
     def update(
@@ -238,7 +237,7 @@ class RuleMiner:
                 NOT_APPLICABLE: [],
                 RESULT: [],
                 INDICES: [],
-                # LOGGING: [],
+                LOG: [],
             }
         )
 
@@ -253,7 +252,7 @@ class RuleMiner:
             NOT_APPLICABLE: "Int64",
             RESULT: "object",
             INDICES: "object",
-            # LOGGING: "object",
+            LOG: "object",
         }
 
         if self.params.get("apply_rules_on_indices", True):
@@ -269,12 +268,12 @@ class RuleMiner:
             rule_group = row[RULE_GROUP]
             rule_status = row[RULE_STATUS]
             rule_code = dataframe_index(expression=rule_def, data=self.data)
-            code_results, code_logging = self.evaluator.evaluate_dict(
+            code_results, code_log = self.evaluator.evaluate_dict(
                 expressions=rule_code, encodings={}
             )
-            code_results = calculate_required_variables(
+            code_results = add_required_variables(
                 required_vars=self.required_vars,
-                code_results=code_results,
+                results=code_results,
             )
             len_results = {
                 key: len(code_results[key])
@@ -289,11 +288,12 @@ class RuleMiner:
             )
 
             co_indices = code_results[VAR_X_AND_Y]
-            # co_logging = code_logging[VAR_X_AND_Y]
             ex_indices = code_results[VAR_X_AND_NOT_Y]
-            # ex_logging = code_logging[VAR_X_AND_NOT_Y]
             na_indices = code_results[VAR_NOT_X]
-            # na_logging = code_logging[VAR_NOT_X]
+            if code_log is not None:
+                co_log = code_log[code_results[VAR_X_AND_Y]]
+                ex_log = code_log[code_results[VAR_X_AND_NOT_Y]]
+                # na_log = code_log[VAR_NOT_X]
 
             if co_indices is not None and not isinstance(co_indices, float):
                 nco = len(co_indices)
@@ -324,7 +324,9 @@ class RuleMiner:
                     results[NOT_APPLICABLE].extend([rule_metrics[NOT_APPLICABLE]] * nco)
                     results[RESULT].extend([True] * nco)
                     results[INDICES].extend(co_indices)
-                    # results[LOGGING].extend(co_logging)
+                    results[LOG].extend(
+                        co_log if code_log is not None else [None] * nco
+                    )
 
             if self.params.get("output_exceptions", True):
                 if nex > 0:
@@ -342,7 +344,9 @@ class RuleMiner:
                     results[NOT_APPLICABLE].extend([rule_metrics[NOT_APPLICABLE]] * nex)
                     results[RESULT].extend([False] * nex)
                     results[INDICES].extend(ex_indices)
-                    # results[LOGGING].extend(ex_logging)
+                    results[LOG].extend(
+                        ex_log if code_log is not None else [None] * nex
+                    )
 
             if self.params.get("output_not_applicable", False):
                 if (nco == 0 and nex == 0) and nna > 0:
@@ -358,7 +362,7 @@ class RuleMiner:
                     results[NOT_APPLICABLE].extend([rule_metrics[NOT_APPLICABLE]])
                     results[RESULT].extend([None])
                     results[INDICES].extend([None])
-                    # results[LOGGING].extend([None])
+                    results[LOG].extend([None])
 
             logger.info(
                 "Finished: "
@@ -623,18 +627,28 @@ class RuleMiner:
                     reformulated_expression = self.parser.parse(candidate)
                     if sorted_expression not in sorted_expressions.keys():
                         sorted_expressions[sorted_expression] = True
-                        rule_code = dataframe_lengths(
+                        rule_code = dataframe_index(
                             expression=reformulated_expression,
-                            required=self.required_vars,
                             data=self.data,
                         )
-                        len_results, _ = self.evaluator.evaluate_dict(
-                            expressions=rule_code,
-                            encodings={},
+                        code_results, _ = self.evaluator.evaluate_dict(
+                            expressions=rule_code, encodings={}
                         )
+                        code_results = add_required_variables(
+                            required_vars=self.required_vars,
+                            results=code_results,
+                        )
+                        len_results = {
+                            key: len(code_results[key])
+                            if not isinstance(code_results[key], float)
+                            else 0
+                            for key in code_results.keys()
+                            if code_results[key] is not None
+                        }
                         rule_metrics = calculate_metrics(
                             len_results=len_results, metrics=self.metrics
                         )
+
                         logger.debug(
                             "Rule code: \n"
                             + str(
@@ -952,6 +966,7 @@ class RuleMiner:
             [metrics[metric] >= self.filter[metric] for metric in self.filter]
         )
 
+
 def flatten_and_sort(expression: str = ""):
     """
     Recursively flatten and sort a nested expression and return it as a string.
